"""
Blessed Mailchimp connector for Airbyte SDK.

Auto-generated from OpenAPI specification.
"""

from .connector import MailchimpConnector
from .models import (
    MailchimpAuthConfig,
    CampaignReportSummaryEcommerce,
    CampaignReportSummary,
    CampaignDeliveryStatus,
    CampaignSettings,
    CampaignTracking,
    CampaignRecipients,
    Campaign,
    CampaignsList,
    ListCampaignDefaults,
    ListStats,
    ListContact,
    List,
    ListsList,
    ListMemberLocation,
    ListMemberStatsEcommerceData,
    ListMemberStats,
    ListMemberTagsItem,
    ListMember,
    ListMembersList,
    ReportClicks,
    ReportListStats,
    ReportFacebookLikes,
    ReportIndustryStats,
    ReportDeliveryStatus,
    ReportEcommerce,
    ReportBounces,
    ReportOpens,
    ReportForwards,
    Report,
    ReportsList,
    EmailActivityActivityItem,
    EmailActivity,
    EmailActivityList,
    AutomationReportSummary,
    AutomationSettings,
    AutomationTracking,
    AutomationRecipientsSegmentOpts,
    AutomationRecipients,
    Automation,
    AutomationsList,
    Tag,
    TagsList,
    InterestCategory,
    InterestCategoriesList,
    Interest,
    InterestsList,
    SegmentOptions,
    Segment,
    SegmentsList,
    SegmentMemberStats,
    SegmentMemberLocation,
    SegmentMember,
    SegmentMembersList,
    Unsubscribe,
    UnsubscribesList,
    CampaignsListResultMeta,
    ListsListResultMeta,
    ListMembersListResultMeta,
    ReportsListResultMeta,
    EmailActivityListResultMeta,
    AutomationsListResultMeta,
    TagsListResultMeta,
    InterestCategoriesListResultMeta,
    InterestsListResultMeta,
    SegmentsListResultMeta,
    SegmentMembersListResultMeta,
    UnsubscribesListResultMeta,
    MailchimpCheckResult,
    MailchimpExecuteResult,
    MailchimpExecuteResultWithMeta,
    CampaignsListResult,
    ListsListResult,
    ListMembersListResult,
    ReportsListResult,
    EmailActivityListResult,
    AutomationsListResult,
    TagsListResult,
    InterestCategoriesListResult,
    InterestsListResult,
    SegmentsListResult,
    SegmentMembersListResult,
    UnsubscribesListResult,
    AirbyteSearchMeta,
    AirbyteSearchResult,
    CampaignsSearchData,
    CampaignsSearchResult,
    EmailActivitySearchData,
    EmailActivitySearchResult,
    ListsSearchData,
    ListsSearchResult,
    ReportsSearchData,
    ReportsSearchResult
)
from .types import (
    CampaignsListParams,
    CampaignsGetParams,
    ListsListParams,
    ListsGetParams,
    ListMembersListParams,
    ListMembersGetParams,
    ReportsListParams,
    ReportsGetParams,
    EmailActivityListParams,
    AutomationsListParams,
    TagsListParams,
    InterestCategoriesListParams,
    InterestCategoriesGetParams,
    InterestsListParams,
    InterestsGetParams,
    SegmentsListParams,
    SegmentsGetParams,
    SegmentMembersListParams,
    UnsubscribesListParams,
    AirbyteSearchParams,
    AirbyteSortOrder,
    CampaignsSearchFilter,
    CampaignsSearchQuery,
    CampaignsCondition,
    EmailActivitySearchFilter,
    EmailActivitySearchQuery,
    EmailActivityCondition,
    ListsSearchFilter,
    ListsSearchQuery,
    ListsCondition,
    ReportsSearchFilter,
    ReportsSearchQuery,
    ReportsCondition
)
from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig

__all__ = [
    "MailchimpConnector",
    "AirbyteAuthConfig",
    "MailchimpAuthConfig",
    "CampaignReportSummaryEcommerce",
    "CampaignReportSummary",
    "CampaignDeliveryStatus",
    "CampaignSettings",
    "CampaignTracking",
    "CampaignRecipients",
    "Campaign",
    "CampaignsList",
    "ListCampaignDefaults",
    "ListStats",
    "ListContact",
    "List",
    "ListsList",
    "ListMemberLocation",
    "ListMemberStatsEcommerceData",
    "ListMemberStats",
    "ListMemberTagsItem",
    "ListMember",
    "ListMembersList",
    "ReportClicks",
    "ReportListStats",
    "ReportFacebookLikes",
    "ReportIndustryStats",
    "ReportDeliveryStatus",
    "ReportEcommerce",
    "ReportBounces",
    "ReportOpens",
    "ReportForwards",
    "Report",
    "ReportsList",
    "EmailActivityActivityItem",
    "EmailActivity",
    "EmailActivityList",
    "AutomationReportSummary",
    "AutomationSettings",
    "AutomationTracking",
    "AutomationRecipientsSegmentOpts",
    "AutomationRecipients",
    "Automation",
    "AutomationsList",
    "Tag",
    "TagsList",
    "InterestCategory",
    "InterestCategoriesList",
    "Interest",
    "InterestsList",
    "SegmentOptions",
    "Segment",
    "SegmentsList",
    "SegmentMemberStats",
    "SegmentMemberLocation",
    "SegmentMember",
    "SegmentMembersList",
    "Unsubscribe",
    "UnsubscribesList",
    "CampaignsListResultMeta",
    "ListsListResultMeta",
    "ListMembersListResultMeta",
    "ReportsListResultMeta",
    "EmailActivityListResultMeta",
    "AutomationsListResultMeta",
    "TagsListResultMeta",
    "InterestCategoriesListResultMeta",
    "InterestsListResultMeta",
    "SegmentsListResultMeta",
    "SegmentMembersListResultMeta",
    "UnsubscribesListResultMeta",
    "MailchimpCheckResult",
    "MailchimpExecuteResult",
    "MailchimpExecuteResultWithMeta",
    "CampaignsListResult",
    "ListsListResult",
    "ListMembersListResult",
    "ReportsListResult",
    "EmailActivityListResult",
    "AutomationsListResult",
    "TagsListResult",
    "InterestCategoriesListResult",
    "InterestsListResult",
    "SegmentsListResult",
    "SegmentMembersListResult",
    "UnsubscribesListResult",
    "AirbyteSearchMeta",
    "AirbyteSearchResult",
    "CampaignsSearchData",
    "CampaignsSearchResult",
    "EmailActivitySearchData",
    "EmailActivitySearchResult",
    "ListsSearchData",
    "ListsSearchResult",
    "ReportsSearchData",
    "ReportsSearchResult",
    "CampaignsListParams",
    "CampaignsGetParams",
    "ListsListParams",
    "ListsGetParams",
    "ListMembersListParams",
    "ListMembersGetParams",
    "ReportsListParams",
    "ReportsGetParams",
    "EmailActivityListParams",
    "AutomationsListParams",
    "TagsListParams",
    "InterestCategoriesListParams",
    "InterestCategoriesGetParams",
    "InterestsListParams",
    "InterestsGetParams",
    "SegmentsListParams",
    "SegmentsGetParams",
    "SegmentMembersListParams",
    "UnsubscribesListParams",
    "AirbyteSearchParams",
    "AirbyteSortOrder",
    "CampaignsSearchFilter",
    "CampaignsSearchQuery",
    "CampaignsCondition",
    "EmailActivitySearchFilter",
    "EmailActivitySearchQuery",
    "EmailActivityCondition",
    "ListsSearchFilter",
    "ListsSearchQuery",
    "ListsCondition",
    "ReportsSearchFilter",
    "ReportsSearchQuery",
    "ReportsCondition",
]